pub fn is_protected(
set: &HashSet<String>,
comm: &str,
exe: Option<&str>,
) -> boolExpand description
A process is protected if its full executable basename is in set, or,
when the executable is unreadable, if its comm is. comm is truncated to 15
characters by the kernel, so it only matches short names.